Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Markos Zaharioudakis
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Markos Zaharioudakis
Markos Zaharioudakis has proposed merging lp:~zorba-coders/zorba/markos-scratch 
into lp:zorba.

Commit message:
1. Check that namespace uri used in default namespace declaration is a valid one
2. fixed error messages for XQST0070 and XQST0036


Requested reviews:
  Markos Zaharioudakis (markos-za)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572

1. Check that namespace uri used in default namespace declaration is a valid one
2. fixed error messages for XQST0070 and XQST0036
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.
=== modified file 'ChangeLog'
--- ChangeLog	2013-06-19 22:18:54 +
+++ ChangeLog	2013-06-20 09:54:39 +
@@ -32,6 +32,7 @@
   * Fixed bug #1103115 (Timezone units as hours are wrong)
   * Fixed bug #1188280 (casting xs:id to xs:ncname)
   * Fixed bug in casting to xs:NCName
+  * Check that namespace uri used in default namespace declaration is a valid one
   * Fixed bug in error conditions for computed PI constructor
   * Fixed implementation of fn:deep-equal according to latest W3C spec.
   * Must apply document ordering on the domain expression of a FOR clause, if

=== modified file 'src/compiler/translator/translator.cpp'
--- src/compiler/translator/translator.cpp	2013-06-19 19:27:26 +
+++ src/compiler/translator/translator.cpp	2013-06-20 09:54:39 +
@@ -178,15 +178,7 @@
 /***
 
 /
-#define ZANN_CONTAINS( ann ) theAnnotations-contains(AnnotationInternal::ann)
-
-
-/***
-  Check/set certain bool data members of TranslatorImpl: raise error if true
-  already otherwise set to true.
-/
-#define CHK_SINGLE_DECL( state, err ) \
-do { if (state) throw XQUERY_EXCEPTION(err); state = true; } while (0)
+#define ZANN_CONTAINS(ann) theAnnotations-contains(AnnotationInternal::ann)
 
 
 /***
@@ -2204,19 +2196,22 @@
 #ifndef ZORBA_NO_XMLSCHEMA
 
   if (! theImportedSchemas.insert(targetNS.str()).second)
-throw XQUERY_EXCEPTION(err::XQST0058, ERROR_LOC(loc));
+RAISE_ERROR(err::XQST0058, loc, ERROR_PARAMS(targetNS));
 
   if (prefix != NULL)
   {
 if (!prefix-get_default_bit()  targetNS.empty())
 {
-  throw XQUERY_EXCEPTION( err::XQST0057, ERROR_LOC(loc));
+  RAISE_ERROR_NO_PARAMS(err::XQST0057, loc);
 }
 
 zstring pfx = prefix-get_prefix();
 
 if (pfx == xml || pfx == xmlns)
-  RAISE_ERROR(err::XQST0070, loc, ERROR_PARAMS(pfx, ZED(NoRebindPrefix)));
+{
+  RAISE_ERROR(err::XQST0070, loc,
+  ERROR_PARAMS(ZED(XQST0070_ReservedPrefixInImport_2), pfx));
+}
 
 if (prefix-get_default_bit())
   theSctx-set_default_elem_type_ns(targetNS, true, loc);
@@ -2226,7 +2221,7 @@
   }
 
   zstring xsdTNS = zstring(XML_SCHEMA_NS);
-  if ( xsdTNS.compare(targetNS)==0 )
+  if (xsdTNS.compare(targetNS) == 0)
   {
 // Xerces doesn't like importing XMLSchema.xsd schema4schema, so we skip it
 // see Xerces-C++ bug: https://issues.apache.org/jira/browse/XERCESC-1980
@@ -2301,7 +2296,7 @@
   return no_state;
 
 #else
-  throw XQUERY_EXCEPTION(err::XQST0009, ERROR_LOC(loc));
+  RAISE_ERROR_NO_PARAMS(err::XQST0009, loc);
 #endif
 }
 
@@ -2358,7 +2353,7 @@
   return no_state;
 
 #else
-  throw XQUERY_EXCEPTION(err::XQST0009, ERROR_LOC(aLoc));
+  RAISE_ERROR_NO_PARAMS(err::XQST0009, aLoc);
 #endif
 }
 
@@ -2801,7 +2796,7 @@
   theModuleNamespace = v.get_target_namespace();
 
   if (theModuleNamespace.empty())
-throw XQUERY_EXCEPTION(err::XQST0088, ERROR_LOC(loc));
+RAISE_ERROR_NO_PARAMS(err::XQST0088, loc);
 
   if (static_context::is_reserved_module(theModuleNamespace))
   {
@@ -2812,7 +2807,7 @@
   if (theModulePrefix == xml || theModulePrefix == xmlns)
   {
 RAISE_ERROR(err::XQST0070, loc,
-ERROR_PARAMS(theModulePrefix, ZED(NoRebindPrefix)));
+ERROR_PARAMS(ZED(XQST0070_ReservedPrefixInModule_2), theModulePrefix));
   }
 
   theSctx-bind_ns(theModulePrefix, theModuleNamespace, loc);
@@ -2998,7 +2993,12 @@
 void* begin_visit(const BoundarySpaceDecl v)
 {
   TRACE_VISIT();
-  CHK_SINGLE_DECL (hadBSpaceDecl, err::XQST0068);
+
+  if (hadBSpaceDecl)
+RAISE_ERROR_NO_PARAMS(err::XQST0068, loc);
+
+  hadBSpaceDecl = true;
+
   theSctx-set_boundary_space_mode(v.get_boundary_space_mode());
   return NULL;
 }
@@ -3015,7 +3015,12 @@
 void* begin_visit(const OrderingModeDecl v)
 {
   TRACE_VISIT();
-  CHK_SINGLE_DECL(hadOrdModeDecl, err::XQST0065);
+
+  if (hadOrdModeDecl)
+RAISE_ERROR_NO_PARAMS(err::XQST0065, loc);
+
+  hadOrdModeDecl = true;
+
   theSctx-set_ordering_mode(v.get_mode());
   return NULL;
 }
@@ 

[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/markos-scratch-2013-06-20T10-02-14.106Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba 
failed. Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:281 
(message):
  Validation queue job markos-scratch-2013-06-20T10-02-14.106Z is finished.
  The final status was:

  

  4 tests did not succeed - changes not commited.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Chris Hillery
Chris Hillery has proposed merging lp:~zorba-coders/zorba/fix-tutorial-schema 
into lp:zorba.

Requested reviews:
  Chris Hillery (ceejatec)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582

This fixes tests on the RQ broken by the http://www.zorba-xquery.com/ upgrade.
-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.
=== modified file 'doc/cxx/examples/uri_resolvers.cpp'
--- doc/cxx/examples/uri_resolvers.cpp	2013-05-28 00:58:27 +
+++ doc/cxx/examples/uri_resolvers.cpp	2013-06-20 11:07:28 +
@@ -41,7 +41,7 @@
   return;
 }
 if(aUri == http://www.zorba-xquery.com/helloworld;) {
-  oUris.push_back(http://www.zorba-xquery.com/tutorials/helloworld.xsd;);
+  oUris.push_back(http://zorbatest.lambda.nu:8080/tutorial/helloworld.xsd;);
 }
   }
 };

=== modified file 'doc/zorba/uriresolvers.dox'
--- doc/zorba/uriresolvers.dox	2013-02-07 17:24:36 +
+++ doc/zorba/uriresolvers.dox	2013-06-20 11:07:28 +
@@ -377,7 +377,7 @@
  return;
}
if(aUri == http://www.example.com/helloworld;) {
- oUris.push_back(http://examples.com/schemas/helloworld.xsd;);
+ oUris.push_back(http://example.com/schemas/helloworld.xsd;);
}
  }
};

=== modified file 'test/api/import-hello.xsd'
--- test/api/import-hello.xsd	2012-04-24 10:17:48 +
+++ test/api/import-hello.xsd	2013-06-20 11:07:28 +
@@ -2,6 +2,6 @@
 xmlns=http://www.zorba-xquery.com/import-hello;
 targetNamespace=http://www.zorba-xquery.com/import-hello;
 elementFormDefault=qualified
-  xs:import schemaLocation=http://www.zorba-xquery.com/tutorials/helloworld.xsd/
+  xs:import schemaLocation=http://zorbatest.lambda.nu:8080/tutorial/helloworld.xsd/
 /xs:schema
 

=== modified file 'test/api/userdefined_uri_resolution.cpp'
--- test/api/userdefined_uri_resolution.cpp	2013-02-07 17:24:36 +
+++ test/api/userdefined_uri_resolution.cpp	2013-06-20 11:07:28 +
@@ -46,7 +46,7 @@
   return;
 }
 if(aUri == http://www.zorba-xquery.com/helloworld;) {
-  oUris.push_back(http://www.zorba-xquery.com/tutorials/helloworld.xsd;);
+  oUris.push_back(http://zorbatest.lambda.nu:8080/tutorial/helloworld.xsd;);
 }
   }
 };
@@ -84,7 +84,7 @@
 std::vectorzorba::String oUris) throw ()
   {
 // Deny access to an URI that would otherwise work
-if(aUri == http://www.zorba-xquery.com/tutorials/helloworld.xsd; ||
+if(aUri == http://zorbatest.lambda.nu:8080/tutorial/helloworld.xsd; ||
aUri == http://www.zorba-xquery.com/modules/fetch; ||
aUri == http://expath.org/ns/file;) {
   oUris.push_back(URIMapper::DENY_ACCESS);
@@ -324,7 +324,7 @@
   try {
 XQuery_t lQuery = aZorba-compileQuery
   (import schema namespace lm=
-'http://www.zorba-xquery.com/tutorials/helloworld.xsd'; 
+'http://zorbatest.lambda.nu:8080/tutorial/helloworld.xsd'; 
 validate{ pHello World!/p }, lContext);
 std::cout  lQuery  std::endl;
   } catch (ZorbaException e) {

=== modified file 'test/api/validate.cpp'
--- test/api/validate.cpp	2013-02-07 17:24:36 +
+++ test/api/validate.cpp	2013-06-20 11:07:28 +
@@ -41,7 +41,7 @@
   return;
 }
 if(aUri == http://www.zorba-xquery.com/helloworld;) {
-  oUris.push_back(http://www.zorba-xquery.com/tutorials/helloworld.xsd;);
+  oUris.push_back(http://zorbatest.lambda.nu:8080/tutorial/helloworld.xsd;);
 }
   }
 };

=== added directory 'test/http-test-data/docroot/tutorial'
=== added file 'test/http-test-data/docroot/tutorial/helloworld.xsd'
--- test/http-test-data/docroot/tutorial/helloworld.xsd	1970-01-01 00:00:00 +
+++ test/http-test-data/docroot/tutorial/helloworld.xsd	2013-06-20 11:07:28 +
@@ -0,0 +1,1 @@
+?xml version='1.0'?xsd:schema xmlns:xsd='http://www.w3.org/2001/XMLSchema'xsd:element name='p' type='xsd:string'//xsd:schema

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Chris Hillery
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Chris Hillery
The proposal to merge lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba 
has been updated.

Commit Message changed to:

Moved tutorial schema into same pool as http-test-data; updated URIs.

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Markos Zaharioudakis
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba 
has been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/fix-tutorial-schema-2013-06-20T11-10-47.267Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Markos Zaharioudakis
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue job fix-tutorial-schema-2013-06-20T11-10-47.267Z is finished. 
The final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba

2013-06-20 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/fix-tutorial-schema into lp:zorba 
has been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
-- 
https://code.launchpad.net/~zorba-coders/zorba/fix-tutorial-schema/+merge/170582
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/markos-scratch-2013-06-20T11-36-56.639Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/json-http-module into lp:zorba

2013-06-20 Thread Federico Cavalieri
 In the Doc examples use WWW.zorba.io... but the module is registered without
 WWW:
 
 xqDoc:
 import module namespace http=http://www.zorba.io/modules/http-client;;
 http:get(http://www.example.com;)

Fixed

 timeout option has a bug. Uncomment timeout in the following script and 
 get this error:
 $ ./zorba -i -f -q q.jq
 error [zerr:ZSTR0040]: type error: Item::getIntValue() not defined for type 
 xs:integer
Fixed and added test

-- 
https://code.launchpad.net/~zorba-coders/zorba/json-http-module/+merge/169579
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/json-http-module into lp:zorba

2013-06-20 Thread Federico Cavalieri
  Cezar, it is not necessary for users to have a jsoniq version header in
 their
  queries to use this module. They can use (field) object accessors instead
 of
  .field .
 
 My point was to mention these options somewhere in the doc and link to a page
 which better describes this. IMHO it's confusing if you also count in the file
 extension .jq.

The file extension is .xq, should I make it .jq?
Thanks
-- 
https://code.launchpad.net/~zorba-coders/zorba/json-http-module/+merge/169579
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue job markos-scratch-2013-06-20T11-36-56.639Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/markos-scratch into lp:zorba

2013-06-20 Thread noreply
The proposal to merge lp:~zorba-coders/zorba/markos-scratch into lp:zorba has 
been updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
-- 
https://code.launchpad.net/~zorba-coders/zorba/markos-scratch/+merge/170572
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/json-http-module into lp:zorba

2013-06-20 Thread Federico Cavalieri
  Cezar, it is not necessary for users to have a jsoniq version header in
 their
  queries to use this module. They can use (field) object accessors instead
 of
  .field .
 
 My point was to mention these options somewhere in the doc and link to a page
 which better describes this. IMHO it's confusing if you also count in the file
 extension .jq.

I added a small note which says that the module is written in jsoniq and that 
can be imported
both by xquery and jsoniq modules.
However, I don't know which webpage should I link to explain the version 
declaration: jsoniq.org does not mention this header, which I only found 
discussed in http://www.zorba.io/blog/. A link to this page would soon become 
outdated and I don't know how to get the specific post url. Any suggestions?
Thanks
-- 
https://code.launchpad.net/~zorba-coders/zorba/json-http-module/+merge/169579
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Paul J. Lucas
Paul J. Lucas has proposed merging lp:~zorba-coders/zorba/bug-1158052 into 
lp:zorba.

Commit message:
Cleaned up both public and internal API.

Requested reviews:
  Paul J. Lucas (paul-lucas)
Related bugs:
  Bug #1158052 in Zorba: createBase64Binary() API too subtle
  https://bugs.launchpad.net/zorba/+bug/1158052

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725

Cleaned up both public and internal API.
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.
=== modified file 'ChangeLog'
--- ChangeLog	2013-06-20 12:00:37 +
+++ ChangeLog	2013-06-21 01:08:30 +
@@ -29,10 +29,11 @@
   * Fixed bug #1190261 (relative paths bug in file module)
   * Fixed bug #1187537 (Eliminate (or at least reduce) use of MAX_PATH)
   * Fixed bug #1180220 (Consolidate redundant path/file public APIs)
+  * Fixed bug #1158052 (createBase64Binary() API too subtle)
   * Fixed bug #1103115 (Timezone units as hours are wrong)
   * Fixed bug #1188280 (casting xs:id to xs:ncname)
   * Fixed bug in casting to xs:NCName
-  * Check that namespace uri used in default namespace declaration is a valid one
+  * Check that the namespace URI used in default namespace declaration is valid
   * Fixed bug in error conditions for computed PI constructor
   * Fixed implementation of fn:deep-equal according to latest W3C spec.
   * Must apply document ordering on the domain expression of a FOR clause, if

=== modified file 'include/zorba/item_factory.h'
--- modules/com/zorba-xquery/www/modules/http-client.xq.src/http_response_parser.cpp	2013-06-12 04:55:14 +
+++ modules/com/zorba-xquery/www/modules/http-client.xq.src/http_response_parser.cpp	2013-06-21 01:08:30 +
@@ -329,7 +329,7 @@
 // changed. This required a Base64 encoding stream since the item factory
 // work only builds base64binary and assumes the data is already encoded.
 String lEncoded = base64::encode(aStream);
-return lFactory-createBase64Binary(lEncoded.data(), lEncoded.size());
+return lFactory-createBase64Binary(lEncoded.data(), lEncoded.size(), true);
   }
 
   zorba::Item HttpResponseParser::createXmlItem( std::istream aStream )

=== modified file 'src/api/itemfactoryimpl.cpp'
--- src/api/itemfactoryimpl.cpp	2013-06-18 23:53:59 +
+++ src/api/itemfactoryimpl.cpp	2013-06-21 01:08:30 +
@@ -1,12 +1,12 @@
 /*
  * Copyright 2006-2008 The FLWOR Foundation.
- * 
+ *
  * Licensed under the Apache License, Version 2.0 (the License);
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an AS IS BASIS,
  * WITHOUT WARRANTIES 

Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Paul J. Lucas
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1158052-2013-06-21T01-46-49.193Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Paul J. Lucas
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba failed. 
Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:281 
(message):
  Validation queue job bug-1158052-2013-06-21T01-46-49.193Z is finished.  The
  final status was:

  

  No tests were run - build or configure step must have failed.

  Not commiting changes.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/json-http-module into lp:zorba

2013-06-20 Thread Matthias Brantner
 Cezar, it is not necessary for users to have a jsoniq version header in
 their
 queries to use this module. They can use (field) object accessors instead
 of
 .field .
 
 My point was to mention these options somewhere in the doc and link to a page
 which better describes this. IMHO it's confusing if you also count in the 
 file
 extension .jq.
 
 I added a small note which says that the module is written in jsoniq and that 
 can be imported
 both by xquery and jsoniq modules.
 However, I don't know which webpage should I link to explain the version 
 declaration: jsoniq.org does not mention this header, which I only found 
 discussed in http://www.zorba.io/blog/. A link to this page would soon become 
 outdated and I don't know how to get the specific post url. Any suggestions?
 Thanks
I think that's fine. Leave it like this. Zorba still has to catch up to make 
.jq modules
possible. Once this is done, we need some general documentation for such cases.

 -- 
 https://code.launchpad.net/~zorba-coders/zorba/json-http-module/+merge/169579
 You are subscribed to branch lp:zorba.


-- 
https://code.launchpad.net/~zorba-coders/zorba/json-http-module/+merge/169579
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/json-http-module into lp:zorba

2013-06-20 Thread Chris Hillery
IMHO, it's not a good idea to have any notes in module docs about how to use 
JSONiq. Virtually ask of our modules will have the same concerns, so we'd need 
to duplicate it dozens of times. This isn't the appropriate location for that 
information. I would take out that doc.
-- 
https://code.launchpad.net/~zorba-coders/zorba/json-http-module/+merge/169579
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/environ-mac-fix into lp:zorba/process-module

2013-06-20 Thread Paul J. Lucas
Paul J. Lucas has proposed merging lp:~zorba-coders/zorba/environ-mac-fix into 
lp:zorba/process-module.

Commit message:
Fix for Mac.

Requested reviews:
  Paul J. Lucas (paul-lucas)

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/environ-mac-fix/+merge/170732

Fix for Mac.
-- 
https://code.launchpad.net/~zorba-coders/zorba/environ-mac-fix/+merge/170732
Your team Zorba Coders is subscribed to branch lp:zorba/process-module.
=== modified file 'src/process-2.xq.src/process.cpp'
--- src/process-2.xq.src/process.cpp	2013-06-13 11:27:11 +
+++ src/process-2.xq.src/process.cpp	2013-06-21 03:40:32 +
@@ -51,6 +51,7 @@
 #ifndef WIN32
 int execvpe(const char *program, char **argv, char **envp)
 {
+  extern char **environ;
   char **saved = environ;
   int rc;
   environ = envp;

--- include/zorba/item_factory.h	2013-06-18 23:53:59 +
+++ include/zorba/item_factory.h	2013-06-21 01:08:30 +
@@ -141,32 +141,26 @@
   /** \brief Creates a Base64Binary Item
* see [http://www.w3.org/TR/xmlschema-2/#base64Binary]
*
    * @param aBinData a pointer to the base64 encoded data. The data is copied from aBinData.
    * @param aLength the length of the base64 encoded data.
* @return The Base64Binary Item.
*/
   virtual Item
-  createBase64Binary(const char* aBinData, size_t aLength) = 0;
+  createBase64Binary(const char* aData, size_t aLength, bool aIsBase64) = 0;
 
   /** \brief Creates a Base64Binary Item
* see [http://www.w3.org/TR/xmlschema-2/#base64Binary]
*
-   * @param aStream A stream containing the Base64 encoded data. The data is copied from aStream imediately.
+   * @param aStream A stream containing the Base64 encoded data.
+   * The data is copied from aStream immediately.
* @return the Base64Binary Item.
*/
   virtual Item
   createBase64Binary(std::istream aStream) = 0;
 
-  /** \brief Creates a Base64Binary Item
-   * see [http://www.w3.org/TR/xmlschema-2/#base64Binary]
-   *
-   * @param aBinData the data in binary form (not encoded). The data is copied from aBinData.
-   * @param aLength the length of the binary data
-   * @return the Base64Binary Item.
-   */
-  virtual Item
-  createBase64Binary(const unsigned char* aBinData, size_t aLength) = 0;
-
   /** \brief Creates a streamable Base64Binary Item
@@ -141,32 +141,26 @@
* see [http://www.w3.org/TR/xmlschema-2/#base64Binary]
*
-   * @param aBinData a pointer to the base64 encoded data. The data is copied from aBinData.
-   * @param aLength the length of the base64 encoded data.
+   * @param aData a pointer to the data.
+   * @param aLength the length of the data (in bytes).
+   * @param aIsBase64 If \c true, \a aBinData is already Base-64 encoded;
+   * if \c false, \a aBinData is binary data that will first be Base-64
+   * encoded.
* @return The Base64Binary Item.
*/
* see [http://www.w3.org/TR/xmlschema-2/#base64Binary]
*

=== modified file 'modules/com/zorba-xquery/www/modules/http-client.xq.src/http_response_parser.cpp'
-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/environ-mac-fix into lp:zorba/process-module

2013-06-20 Thread Paul J. Lucas
Review: Approve


-- 
https://code.launchpad.net/~zorba-coders/zorba/environ-mac-fix/+merge/170732
Your team Zorba Coders is subscribed to branch lp:zorba/process-module.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Paul J. Lucas
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
There are additional revisions which have not been approved in review. Please 
seek review and approval of these new revisions.
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Paul J. Lucas
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~paul-lucas/zorba/bug-1189636 into lp:zorba

2013-06-20 Thread Federico Cavalieri
Review: Approve


-- 
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~paul-lucas/zorba/bug-1189636 into lp:zorba

2013-06-20 Thread Federico Cavalieri
The proposal to merge lp:~paul-lucas/zorba/bug-1189636 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
-- 
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1158052-2013-06-21T03-54-45.43Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba failed. 
Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:281 
(message):
  Validation queue job bug-1158052-2013-06-21T03-54-45.43Z is finished.  The
  final status was:

  

  No tests were run - build or configure step must have failed.

  Not commiting changes.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~paul-lucas/zorba/bug-1189636 into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1189636-2013-06-21T04-02-04.513Z/log.html
-- 
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~paul-lucas/zorba/bug-1189636 into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue job bug-1189636-2013-06-21T04-02-04.513Z is finished. The 
final status was:

All tests succeeded!
-- 
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~paul-lucas/zorba/bug-1189636 into lp:zorba

2013-06-20 Thread noreply
The proposal to merge lp:~paul-lucas/zorba/bug-1189636 into lp:zorba has been 
updated.

Status: Approved = Merged

For more details, see:
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
-- 
https://code.launchpad.net/~paul-lucas/zorba/bug-1189636/+merge/170471
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Paul J. Lucas
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Needs review = Approved

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
Validation queue starting for merge proposal.
Log at: 
http://zorbatest.lambda.nu:8080/remotequeue/bug-1158052-2013-06-21T04-31-56.775Z/log.html
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


Re: [Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The attempt to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba failed. 
Below is the output from the failed tests.


CMake Error at /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake:281 
(message):
  Validation queue job bug-1158052-2013-06-21T04-31-56.775Z is finished.  The
  final status was:

  

  No tests were run - build or configure step must have failed.

  Not commiting changes.


Error in read script: /home/ceej/zo/testing/zorbatest/tester/TarmacLander.cmake

-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp


[Zorba-coders] [Merge] lp:~zorba-coders/zorba/bug-1158052 into lp:zorba

2013-06-20 Thread Zorba Build Bot
The proposal to merge lp:~zorba-coders/zorba/bug-1158052 into lp:zorba has been 
updated.

Status: Approved = Needs review

For more details, see:
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
-- 
https://code.launchpad.net/~zorba-coders/zorba/bug-1158052/+merge/170725
Your team Zorba Coders is subscribed to branch lp:zorba.

-- 
Mailing list: https://launchpad.net/~zorba-coders
Post to : zorba-coders@lists.launchpad.net
Unsubscribe : https://launchpad.net/~zorba-coders
More help   : https://help.launchpad.net/ListHelp